#! /bin/sh

# This script is used to prepare the package for Qt4
#
# 1/ Download the precompiled win32 installer
# 2/ Install it
# 3/ You get a folder with 
#   include/
#       QtCore
#       QtGui
#       QtOtherStuff
#   src/
#       corelib/
#       gui/
#       otherstuff/
#   lib/
#
# 4/ Copy the needed files to make the layout like this :
#    (not yet automated)
#   include/
#       qt4/
#          QtCore/
#           QtGui/
#           src/
#               corelib/
#               gui/
#   lib/
#
# 5/ Copy this script in the directory with include/ and lib/
# 6/ Run it with VERSION as argument
# 7/ You now have a qt4-$VERSION.tar.gz in ../

VERSION=$1
echo "[+] Fixing include pathes"
# 1 / Fix the paths in the include files
for file in `find include/qt4/QtCore -type f -name '*h'` `find include/qt4/QtGui -type f -name '*h'`
do
    mv $file $file.tmp
    sed 's,..\/..\/src,..\/src,' $file.tmp > $file
    rm -f $file.tmp
done

# 2/ Remove the source files
echo "[+] Removing source files"
find include/qt4/src/corelib -name "*cpp"|xargs rm
find include/qt4/src/gui -name "*cpp"|xargs rm

# 3/ Create the PC files
echo "[+] Creating pkgconfig files"
mkdir -p lib/pkgconfig
rm -f lib/pkgconfig/QtCore.pc.in
cat > lib/pkgconfig/QtCore.pc.in << EOF
prefix=@@PREFIX@@
exec_prefix=\${prefix}
libdir=\${prefix}/lib
includedir=\${prefix}/include/qt4/QtCore

Name: Qtcore
Description: Qtcore Library
Version: $VERSION
Libs: \${libdir}/libQtCore4.a -lz -lm
Cflags: -DQT_SHARED -I\${prefix}/include/qt4 -I\${includedir}
EOF

rm -f lib/pkgconfig/QtGui.pc.in
cat > lib/pkgconfig/QtGui.pc.in << EOF
prefix=@@PREFIX@@
exec_prefix=\${prefix}
libdir=\${prefix}/lib
includedir=\${prefix}/include/qt4/QtGui

Name: Qtgui
Description: Qtgui Library
Version: 4.1.3
Libs: \${libdir}/libQtCore4.a \${libdir}/libQtGui4.a -lm  
Cflags: -DQT_SHARED -I\${prefix}/include/qt4 -I\${includedir}
EOF

# 4/ Keep the script
echo "[+] Copying scripts"
mkdir -p bin
cp $0 bin/
cp /usr/bin/moc-qt4 bin/moc
cp /usr/bin/uic-qt4 bin/uic
cp /usr/bin/rcc bin/rcc

# 5/ create packages
echo "[+] Creating tarball"
rm -rf qt4-$VERSION
mkdir qt4-$VERSION-bin-win32
cp -r include bin lib qt4-$VERSION-bin-win32
tar cz qt4-$VERSION-bin-win32 > qt4-$VERSION-bin-win32.tar.gz
